@@ -58,6 +58,12 @@ def get_flask_app(cfg):
     return app
 
 
+# for uWSGI
+def get_app():
+    cfg = get_config()
+    return get_flask_app(cfg)
+
+
 if __name__ == "__main__":
     cfg = get_config()
     app = get_flask_app(cfg)
